// Copyright (c) 2023 mStar
// 
// Licensed under the EUPL, Version 1.2
// 
// You may not use this work except in compliance with the Licence.
// You should have received a copy of the Licence along with this work. If not, see:
// <https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12>.
// See the Licence for the specific language governing permissions and limitations under the Licence.

use tokio::fs::File;

mod sqlite;
mod postgres;

pub type MessageID = i64;
pub type MediaID = i64;


pub trait StorageAccess {
    fn store_message<E>(user: &str, message: &str) -> Result<MediaID, E>;
    fn get_message<E>(user: &str, id: &MessageID) -> Result<String, E>;
    fn delete_message<T, E>(id: &MessageID) -> Result<T, E>;
    fn edit_message<T, E>(id: &MessageID, message: &str) -> Result<T, E>;

    fn store_media<E>(f: &File, nsfw: bool, alt_text: Option<&str>) -> Result<MediaID, E>;
    fn get_media<E>(id: &MediaID) -> Result<(File, bool, Option<String>), E>;
    fn delete_media<T, E>(id: &MediaID) -> Result<T, E>;
    // No edit media because how? Editing media in a message replaces the media, not edits it
}
